@@ -1,25 +1,36 @@
+import re
 from .logger import Logger
 from .config import Configs
 from .providers import StoreProvider, Providers
 from .stages import Stages
+from .constants import *
+from .exceptions import *
+
 
 class ParameterProvider(StoreProvider):
-    def list(self, stage, uninherited, format):
+    def add(self, project, application, stage, key, value):
         raise NotImplementedError()
-    def add(self, stage, key, value):
+    def list(self, project, application, stage, uninherited):
         raise NotImplementedError()
-    def delete(self, stage, key):
+    def get(self, project, application, stage, key, revision=None):
         raise NotImplementedError()
-    def get(self, stage, key):
+    def delete(self, project, application, stage, key):
         raise NotImplementedError()
+    def history(self, project, application, stage, key):
+        raise NotImplementedError()
+
 
 class ParameterManager():
 
     def validate_key(self, key):
-        provider = Providers.ParameterProvider()
         Logger.info("Start validating parameter key...")
-        return provider.validate_key(key)
-
+        Logger.debug(f"Validating: key={key}")
+        pattern = REGEX_PATTERNS['parameter_key']
+        if not re.match(pattern, key):
+            raise DSOException(MESSAGES['InvalidKeyPattern'].format(key, pattern))
+        if '..' in key:
+            raise DSOException(MESSAGES['InvalidKeyStr'].format(key, '..'))
+            
     def list(self, stage, uninherited):
         project = Configs.project
         application = Configs.application
