@@ -50,14 +50,6 @@ class AwsSsmParameterProvider(ParameterProvider):
             result += f"/{key}"
         return result
 
-
-###--------------------------------------------------------------------------------------------
-
-    def get_key_validator(self):
-
-        # return r"^([a-zA-Z][a-zA-Z0-9]*/)?([a-zA-Z][a-zA-Z0-9_.-]*)$"
-        return r"^([a-zA-Z][a-zA-Z0-9_.-]*)$"
-
 ###--------------------------------------------------------------------------------------------
 
     def assert_no_scope_overwrites(self, project, application, stage, key):
@@ -111,7 +103,7 @@ class AwsSsmParameterProvider(ParameterProvider):
             if key in parameters:
                 Logger.warn("Inherited parameter '{0}' overridden.".format(key))
             parameters[key] = {'Value': parameter['Value'], 
-                                'Path': parameter['Name'][:-len(key)-1],
+                                'Path': parameter['Name'],
                                 'Version': parameter['Version'],
                                 'Date': parameter['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
                             }
@@ -189,7 +181,7 @@ class AwsSsmParameterProvider(ParameterProvider):
         response = ssm.put_parameter(Name=path, Value=value, Type='String', Overwrite=True)
         return {'Key': key, 
                 'Value': value,
-                'Path': path[:-len(key)-1],
+                'Path': path,
                 'RevisionId': str(response['Version']),
                 # 'Version': response['Version'],
                 }
@@ -199,10 +191,10 @@ class AwsSsmParameterProvider(ParameterProvider):
     def get(self, project, application, stage, key, revision=None):
         found = self.locate_parameter(project, application, stage, key)
         if not found:
-            raise DSOException(f"Parameter '{key}' not found: project={project}, application={application}, stage={Stages.shorten(stage)}")
+            raise DSOException(f"Parameter '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         else:
             if not found[0]['Type'] == 'String':
-                raise DSOException(f"Parameter '{key}' not found: project={project}, application={application}, stage={Stages.shorten(stage)}")
+                raise DSOException(f"Parameter '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Getting SSM parameter: path={found[0]['Name']}")
         response = ssm.get_parameter_history(Name=found[0]['Name'])
         parameters = sorted(response['Parameters'], key=lambda x: x['Version'], reverse=True)
@@ -212,7 +204,7 @@ class AwsSsmParameterProvider(ParameterProvider):
                     'RevisionId': str(parameters[0]['Version']),
                     'Key': key, 
                     'Value': parameters[0]['Value'],
-                    'Path': found[0]['Name'][:-len(key)-1],
+                    'Path': found[0]['Name'],
                     'Date': parameters[0]['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
                     'User': parameters[0]['LastModifiedUser'],
                     # 'Version': parameters[0]['Version'],
@@ -221,12 +213,12 @@ class AwsSsmParameterProvider(ParameterProvider):
             ### get specific revision
             parameters = [x for x in parameters if str(x['Version']) == revision]
             if not parameters:
-                raise DSOException(f"Revision '{revision}' not found: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
+                raise DSOException(f"Revision '{revision}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
             result = {
                     'RevisionId':str(parameters[0]['Version']),
                     'Key': key, 
                     'Value': parameters[0]['Value'],
-                    'Path': found[0]['Name'][:-len(key)-1],
+                    'Path': found[0]['Name'],
                     'Date': parameters[0]['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
                     'User': parameters[0]['LastModifiedUser'],
                     # 'Version': parameters[0]['Version'],
@@ -239,10 +231,10 @@ class AwsSsmParameterProvider(ParameterProvider):
     def history(self, project, application, stage, key):
         found = self.locate_parameter(project, application, stage, key)
         if not found:
-            raise DSOException(f"Parameter '{key}' not found: project={project}, application={application}, stage={Stages.shorten(stage)}")
+            raise DSOException(f"Parameter '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         else:
             if not found[0]['Type'] == 'String':
-                raise DSOException(f"Parameter '{key}' not found: project={project}, application={application}, stage={Stages.shorten(stage)}")
+                raise DSOException(f"Parameter '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Getting SSM parameter: path={found[0]['Name']}")
         response = ssm.get_parameter_history(Name=found[0]['Name'])
         parameters = sorted(response['Parameters'], key=lambda x: x['Version'], reverse=True)
@@ -251,7 +243,7 @@ class AwsSsmParameterProvider(ParameterProvider):
                 'RevisionId': str(parameter['Version']),
                 'Key': key,
                 'Value': parameter['Value'],
-                'Path': found[0]['Name'][:-len(key)-1],
+                'Path': found[0]['Name'],
                 'Date': parameter['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
                 'User': parameter['LastModifiedUser'],
                 # 'Version': parameter['Version'],
@@ -267,15 +259,18 @@ class AwsSsmParameterProvider(ParameterProvider):
         ### only parameters owned by the stage can be deleted, hence uninherited=True
         found = self.locate_parameter(project, application, stage, key, uninherited=True)
         if not found:
-            raise DSOException(f"Parameter '{key}' not found: project={project}, application={application}, stage={Stages.shorten(stage)}")
+            raise DSOException(f"Parameter '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         else:
             # if len(found) > 1:
             #     Logger.warn(f"More than one parameter found at '{found[0]['Name']}'. The first one taken, and the rest were discarded.")
             if not found[0]['Type'] == 'String':
-                raise DSOException(f"Parameter '{key}' not found: project={project}, application={application}, stage={Stages.shorten(stage)}")
+                raise DSOException(f"Parameter '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Deleting SSM parameter: path={found[0]['Name']}")
         response = ssm.delete_parameter(Name=found[0]['Name'])
-        return {'Key': key, 'Path': found[0]['Name'][:-len(key)-1]}
+        return {
+                'Key': key, 
+                'Path': found[0]['Name'],
+                }
 
 ###--------------------------------------------------------------------------------------------
 ###--------------------------------------------------------------------------------------------
