@@ -51,14 +51,6 @@ class AwsSsmSecretProvider(SecretProvider):
             result += f"/{key}"
         return result
 
-
-###--------------------------------------------------------------------------------------------
-
-    def get_key_validator(self):
-
-        # return r"^([a-zA-Z][a-zA-Z0-9]*/)?([a-zA-Z][a-zA-Z0-9_.-]*)$"
-        return r"^([a-zA-Z][a-zA-Z0-9_.-]*)$"
-
 ###--------------------------------------------------------------------------------------------
 
     def assert_no_scope_overwrites(self, project, application, stage, key):
@@ -113,7 +105,7 @@ class AwsSsmSecretProvider(SecretProvider):
             if key in secrets:
                 Logger.warn("Inherited secret '{0}' overridden.".format(key))
             secrets[key] = {'Value': secret['Value'], 
-                                'Path': secret['Name'][:-len(key)-1],
+                                'Path': secret['Name'],
                                 'Version': secret['Version'],
                                 'Date': secret['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
                             }
@@ -191,7 +183,7 @@ class AwsSsmSecretProvider(SecretProvider):
         response = ssm.put_parameter(Name=path, Value=value, Type='SecureString', Overwrite=True)
         return {'Key': key, 
                 'Value': value,
-                'Path': path[:-len(key)-1],
+                'Path': path,
                 'RevisionId': str(response['Version']),
                 # 'Version': response['Version'],
                 }
@@ -201,10 +193,10 @@ class AwsSsmSecretProvider(SecretProvider):
     def get(self, project, application, stage, key, revision=None):
         found = self.locate_secret(project, application, stage, key)
         if not found:
-            raise DSOException(f"Secret '{key}' not found: project={project}, application={application}, stage={Stages.shorten(stage)}")
+            raise DSOException(f"Secret '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         else:
             if not found[0]['Type'] == 'SecureString':
-                raise DSOException(f"Parameter '{key}' not found: project={project}, application={application}, stage={Stages.shorten(stage)}")
+                raise DSOException(f"Parameter '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Getting SSM secret: path={found[0]['Name']}")
         response = ssm.get_parameter_history(Name=found[0]['Name'], WithDecryption=True)
         secrets = sorted(response['Parameters'], key=lambda x: x['Version'], reverse=True)
@@ -214,7 +206,7 @@ class AwsSsmSecretProvider(SecretProvider):
                     'RevisionId': str(secrets[0]['Version']),
                     'Key': key, 
                     'Value': secrets[0]['Value'],
-                    'Path': found[0]['Name'][:-len(key)-1],
+                    'Path': found[0]['Name'],
                     'Date': secrets[0]['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
                     'User': secrets[0]['LastModifiedUser'],
                     # 'Version': secrets[0]['Version'],
@@ -223,12 +215,12 @@ class AwsSsmSecretProvider(SecretProvider):
             ### get specific revision
             secrets = [x for x in secrets if str(x['Version']) == revision]
             if not secrets:
-                raise DSOException(f"Revision '{revision}' not found: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
+                raise DSOException(f"Revision '{revision}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
             result = {
                     'RevisionId': str(secrets[0]['Version']),
                     'Key': key, 
                     'Value': secrets[0]['Value'],
-                    'Path': found[0]['Name'][:-len(key)-1],
+                    'Path': found[0]['Name'],
                     'Date': secrets[0]['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
                     'User': secrets[0]['LastModifiedUser'],
                     # 'Version': secrets[0]['Version'],
@@ -241,10 +233,10 @@ class AwsSsmSecretProvider(SecretProvider):
     def history(self, project, application, stage, key):
         found = self.locate_secret(project, application, stage, key)
         if not found:
-            raise DSOException(f"Secret '{key}' not found: project={project}, application={application}, stage={Stages.shorten(stage)}")
+            raise DSOException(f"Secret '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         else:
             if not found[0]['Type'] == 'SecureString':
-                raise DSOException(f"Parameter '{key}' not found: project={project}, application={application}, stage={Stages.shorten(stage)}")
+                raise DSOException(f"Parameter '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Getting SSM secret: path={found[0]['Name']}")
         response = ssm.get_parameter_history(Name=found[0]['Name'], WithDecryption=True)
         secrets = sorted(response['Parameters'], key=lambda x: x['Version'], reverse=True)
@@ -253,7 +245,7 @@ class AwsSsmSecretProvider(SecretProvider):
                 'RevisionId': str(secret['Version']),
                 'Key': key,
                 'Value': secret['Value'],
-                'Path': found[0]['Name'][:-len(key)-1],
+                'Path': found[0]['Name'],
                 'Date': secret['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
                 'User': secret['LastModifiedUser'],
                 # 'Version': secret['Version'],
@@ -268,7 +260,7 @@ class AwsSsmSecretProvider(SecretProvider):
         ### only secrets owned by the stage can be deleted, hence uninherited=True
         found = self.locate_secret(project, application, stage, key, uninherited=True)
         if not found:
-                raise DSOException(f"Secret '{key}' not found: project={project}, application={application}, stage={Stages.shorten(stage)}")
+                raise DSOException(f"Secret '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         else:
             # if len(found) > 1:
             #     Logger.warn(f"More than one secret found at '{found[0]['Name']}'. The first one taken, and the rest were discarded.")
@@ -276,7 +268,10 @@ class AwsSsmSecretProvider(SecretProvider):
                 raise DSOException(f"Secret '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Deleting SSM secret: path={found[0]['Name']}")
         ssm.delete_parameter(Name=found[0]['Name'])
-        return {'Key': key, 'Path': found[0]['Name'][:-len(key)-1]}
+        return {
+                'Key': key, 
+                'Path': found[0]['Name'],
+                }
 
 ###--------------------------------------------------------------------------------------------
 ###--------------------------------------------------------------------------------------------
